#include <QtGui/QApplication>
#include "mainwindow.h"




int main(int argc, char *argv[])
{
    QApplication a(argc, argv);
        a.setOrganizationName("MaeCount");
        a.setOrganizationDomain("www.greg-roberts.com");
        a.setApplicationName("MaeCount");
    MainWindow w;
   // w.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
#if defined(Q_WS_S60)
    w.showMaximized();
#else
    w.show();
#endif

    return a.exec();
}
